@@ -230,8 +230,8 @@ class GPTSeleniumAgent:
 
     def __get_relevant_part_of_stack_trace(self):
         """Get the relevant part of the stack trace."""
-        stack_trace = traceback.format_exc()
-        stack_trace = stack_trace.split("\n")[3:5]
+        original_stack_trace = traceback.format_exc()
+        stack_trace = original_stack_trace.split("\n")[3:5]
         stack_trace = "\n".join(stack_trace)
         # Get the name of this class (GPTSeleniumAgent) and
         # replace it with "env".
