@@ -3,6 +3,11 @@ from llama_index import GPTSimpleVectorIndex, GPTListIndex
 from llama_index import Document, LLMPredictor
 from langchain.chat_models import ChatOpenAI
 
+import logging
+
+logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger(__name__)
+
 # https://gpt-index.readthedocs.io/en/latest/guides/index_guide.html
 INDEX_TYPES = {
     # Good for retrieval, because of top_k and embeddings.
@@ -12,7 +17,7 @@ INDEX_TYPES = {
 }
 
 LLM_PREDICTOR_TYPES = {
-    "chatgpt": ChatOpenAI, 
+    "chatgpt": ChatOpenAI,
 }
 
 # Not sure if we need this level of granularity, but leaving it here for now.
@@ -44,8 +49,13 @@ class Memory:
         predictor_constructor = LLM_PREDICTOR_TYPES[self.llm_predictor]
         llm = predictor_constructor(**kwargs)
         llm_predictor = LLMPredictor(llm=llm)
-        return self.index.query(prompt, llm_predictor=llm_predictor, response_mode=self.synthesis_type)
+        return self.index.query(
+            prompt, llm_predictor=llm_predictor, response_mode=self.synthesis_type
+        )
 
     def add(self, text):
+        if text in self.texts:
+            logger.info("Skipping duplicate text.")
+            return
         self.texts.append(text)
         self.index.insert(Document(text))
